@@ -22,6 +22,7 @@ Example:
 import cv2
 import numpy as np
 from pathlib import Path
+import wsiprocess.annotationparser as parsers
 from .annotationparser.parser_utils import detect_type
 
 
@@ -38,7 +39,7 @@ class Annotation:
         """
         self.path = path
         self.slidename = slidename
-        self.dot_bbox_width = self.dot_bbox_height = 0
+        self.dot_bbox_width = self.dot_bbox_height = False
         self.is_image = is_image
         self.classes = []
         if not self.is_image:
@@ -58,25 +59,15 @@ class Annotation:
         if not annotation_type:
             annotation_type = detect_type(self.path)
         if annotation_type == "ASAP":
-            from .annotationparser.ASAP_parser import AnnotationParser
-            parsed = AnnotationParser(self.path)
+            parsed = parsers.ASAPAnnotation(self.path)
         elif annotation_type == "WSIDissector":
-            from .annotationparser.wsidissector_parser import AnnotationParser
-            parsed = AnnotationParser(self.path)
+            parsed = parsers.WSIDissectorAnnotation(self.path)
         elif annotation_type == "SlideRunner":
-            from .annotationparser.SlideRunner_parser import AnnotationParser
-            parsed = AnnotationParser(self.path, self.slidename)
+            parsed = parsers.SlideRunnerAnnotation(self.path, self.slidename)
         elif annotation_type == "QuPath":
-            from .annotationparser.QuPath_parser import AnnotationParser
-            parsed = AnnotationParser(self.path)
+            parsed = parsers.QuPathAnnotation(self.path)
         elif annotation_type == "Empty":
-            class AnnotationParser:
-                classes = []
-                mask_coords = {}
-
-                def __init__(self, path):
-                    pass
-            parsed = AnnotationParser(self.path)
+            parsed = parsers.BaseParser(self.path)
         self.classes = parsed.classes
         self.mask_coords = parsed.mask_coords
 
@@ -128,7 +119,7 @@ class Annotation:
 
     def make_masks(
             self, slide, rule=False, foreground="otsu", size=2000,
-            min_=30, max_=190):
+            min_=30, max_=190, lambdas=False):
         """Make masks from the slide and rule.
 
         Masks are for each class and foreground area.
@@ -153,7 +144,8 @@ class Annotation:
         self.main_masks()
         if foreground:
             self.make_foreground_mask(
-                slide, size, method=foreground, min_=min_, max_=max_)
+                slide, size, method=foreground, min_=min_, max_=max_,
+                lambdas=lambdas)
         if rule:
             self.classes = list(set(self.classes) & set(rule.classes))
             self.include_masks(rule)
@@ -261,7 +253,8 @@ class Annotation:
             self.mask_coords[cls] = [list(c) for c in base_set]
 
     def make_foreground_mask(
-            self, slide, size=2000, method="otsu", min_=30, max_=190):
+            self, slide, size=2000, method="otsu", min_=30, max_=190,
+            lambdas=False):
         """Make foreground mask.
 
         With otsu thresholding, make simple foreground mask.
@@ -278,6 +271,8 @@ class Annotation:
             max (int, optional): Used if method is "minmax". Annotation object
                 defines foreground as the pixels with the value between "min"
                 and "max".
+            lambdas (list(callable)): List of operations to compute on the
+                mask.
         """
         if "foreground" in self.classes:
             return
@@ -285,8 +280,10 @@ class Annotation:
         thumb_gray = cv2.cvtColor(thumb, cv2.COLOR_RGB2GRAY)
         if method == "minmax":
             mask = self._minmax_mask(thumb_gray, min_, max_)
-        elif callable(method):
-            mask = method(thumb_gray)
+        elif method == "lambdas":
+            mask = thumb_gray
+            for lambd in lambdas:
+                mask = lambd(mask)
         else:
             mask = self._otsu_method_mask(thumb_gray)
         self.masks["foreground"] = cv2.resize(mask, (slide.width,
