@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-from pathlib import Path
 from lxml import etree
 import numpy as np
 
+from .parser_utils import BaseParser
 
-class AnnotationParser:
+
+class ASAPAnnotation(BaseParser):
     """Annotation Parser for ASAP.
 
     Args:
@@ -19,8 +20,7 @@ class AnnotationParser:
     """
 
     def __init__(self, path):
-        self.path = path
-        assert Path(self.path).exists(), "This annotation file does not exist."
+        super().__init__(path)
 
         tree = etree.parse(self.path)
         self.annotations = tree.xpath(
@@ -31,7 +31,6 @@ class AnnotationParser:
             group.attrib["Name"]
             for group in self.annotation_groups
         ]
-        self.mask_coords = {}
         for cls in self.classes:
             self.mask_coords[cls] = []
         self.read_mask_coords()
@@ -52,7 +51,7 @@ class AnnotationParser:
             if annotation.attrib["PartOfGroup"] == cls:
                 contour = []
                 for coord in annotation.xpath("Coordinates/Coordinate"):
-                    x = np.float(coord.attrib["X"])
-                    y = np.float(coord.attrib["Y"])
+                    x = np.float64(coord.attrib["X"])
+                    y = np.float64(coord.attrib["Y"])
                     contour.append([round(float(x)), round(float(y))])
                 self.mask_coords[cls].append(contour)
